370 units (rows) and 10 variables (columns). The columns are:
treat: A binary treatment variable. Equal to 1 if treated in the National Supported Work Demonstration; equal to 0 otherwise.
age: age in years.
educ: years of education.
black: an indicator variable, equal to 1 only if the subject is black.
hispan: an indicator variable, equal to 1 only if the subject is hispanic.
married: an indicator variable, equal to 1 only if the subject is married.
nodegree: an indicator variable, equal to 1 only if the subject does not have a degree.
re74: earnings in 1974.
re75: earnings in 1975.
subclass: The subclass denoting the pairs within the matched dataset.